==> mathjax_2.3.orig.tar.gz: MathJax-2.3/unpacked/localization/br/MathMenu.js <==
/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */

/*************************************************************
 *
 *  MathJax/localization/br/MathMenu.js
 *
 *  Copyright (c) 2009-2013 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

MathJax.Localization.addTranslation("br","MathMenu",{
        version: "2.3",
        isLoaded: true,
        strings: {
          Show: "Diskouez ar formulenn evel",
          MathMLcode: "Kod MathML",
          OriginalMathML: "MathML orin",
          TeXCommands: "Urzhio\u00F9 TeX",
          ErrorMessage: "Kemennadenn fazi",
          Annotation: "Notenn",
          TeX: "TeX",
          StarMath: "StarMath",
          OpenMath: "OpenMath",
          Click: "Klika\u00F1",
          DoubleClick: "Daouglika\u00F1",
          NoZoom: "Zoum ebet",
          Option: "Dibarzh",
          Command: "Urzhiad",
          Control: "Kontroll",
          ZoomFactor: "Feur zoum",
          ForHTMLCSS: "Evit HTML-CSS :",
          Auto: "Emgefre",
          TeXLocal: "TeX (lec'hel)",
          TeXWeb: "TeX (web)",
          TeXImage: "TeX (skeudenn)",
          STIXLocal: "STIX (lec'hel)",
          ContextMenu: "La\u00F1ser kemperzhel",
          Browser: "Merdeer",
          Locale: "Yezh",
          LoadLocale: "Karga\u00F1 diwar an URL ...",
          About: "Diwar-benn MathJax",
          Help: "Sikour MathJax",
          wofforotffonts: "fonto\u00F9 woff pe otf",
          eotffonts: "fonto\u00F9 eot",
          svgfonts: "Fonto\u00F9 svg",
          LoadURL: "Karga\u00F1 roadenno\u00F9 trei\u00F1 eus an URL-ma\u00F1 :",
          Close: "Serri\u00F1",
          Original: "Furmskrid orin",
          Settings: "Arventenno\u00F9 ar matematiko\u00F9"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/br/MathMenu.js");

==> mathjax_2.4.orig.tar.gz: MathJax-2.4/unpacked/localization/br/MathMenu.js <==
/* -*- Mode: Javascript; indent-tabs-mode:nil; js-indent-level: 2 -*- */
/* vim: set ts=2 et sw=2 tw=80: */

/*************************************************************
 *
 *  MathJax/localization/br/MathMenu.js
 *
 *  Copyright (c) 2009-2014 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

MathJax.Localization.addTranslation("br","MathMenu",{
        version: "2.4.0",
        isLoaded: true,
        strings: {
          Show: "Diskouez ar formulenn evel",
          MathMLcode: "Kod MathML",
          OriginalMathML: "MathML orin",
          TeXCommands: "Urzhio\u00F9 TeX",
          Original: "Furmskrid orin",
          ErrorMessage: "Kemennadenn fazi",
          Annotation: "Notenn",
          TeX: "TeX",
          StarMath: "StarMath",
          OpenMath: "OpenMath",
          Settings: "Arventenno\u00F9 ar matematiko\u00F9",
          Click: "Klika\u00F1",
          DoubleClick: "Daouglika\u00F1",
          NoZoom: "Zoum ebet",
          Option: "Dibarzh",
          Command: "Urzhiad",
          Control: "Kontroll",
          ZoomFactor: "Feur zoum",
          ForHTMLCSS: "Evit HTML-CSS :",
          Auto: "Emgefre",
          TeXLocal: "TeX (lec'hel)",
          TeXWeb: "TeX (web)",
          TeXImage: "TeX (skeudenn)",
          STIXLocal: "STIX (lec'hel)",
          STIXWeb: "STIX (web)",
          AsanaMathWeb: "Asana Math (web)",
          GyrePagellaWeb: "Gyre Pagella (web)",
          GyreTermesWeb: "Gyre Termes (web)",
          LatinModernWeb: "Latin Modern (web)",
          NeoEulerWeb: "Neo Euler (web)",
          ContextMenu: "La\u00F1ser kemperzhel",
          Browser: "Merdeer",
          Locale: "Yezh",
          LoadLocale: "Karga\u00F1 diwar an URL ...",
          About: "Diwar-benn MathJax",
          Help: "Sikour MathJax",
          wofforotffonts: "fonto\u00F9 woff pe otf",
          eotffonts: "fonto\u00F9 eot",
          svgfonts: "Fonto\u00F9 svg",
          LoadURL: "Karga\u00F1 roadenno\u00F9 trei\u00F1 eus an URL-ma\u00F1 :",
          Close: "Serri\u00F1",
          EqSource: "Tarzh kevatalenn MathJax"
        }
});

MathJax.Ajax.loadComplete("[MathJax]/localization/br/MathMenu.js");
